==> polymer-core-0.9.19+1.21.1-sources.jar: eu/pb4/polymer/core/mixin/block/ChunkDataSenderMixin.java <==
package eu.pb4.polymer.core.mixin.block;

import ;
import com.llamalad7.mixinextras.injector.v2.WrapWithCondition;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import eu.pb4.polymer.common.api.PolymerCommonUtils;
import eu.pb4.polymer.core.impl.PolymerImplUtils;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

import java.util.BitSet;
import net.minecraft.class_2596;
import net.minecraft.class_2672;
import net.minecraft.class_2818;
import net.minecraft.class_3244;
import net.minecraft.class_3568;
import net.minecraft.class_8608;

@Mixin(value = class_8608.class, priority = 1001)
public class ChunkDataSenderMixin {
    @WrapOperation(method = "sendChunkData", at = @At(value = "NEW", target = "(Lnet/minecraft/world/chunk/WorldChunk;Lnet/minecraft/world/chunk/light/LightingProvider;Ljava/util/BitSet;Ljava/util/BitSet;)Lnet/minecraft/network/packet/s2c/play/ChunkDataS2CPacket;"), require = 0)
    private static class_2672 addContext(class_2818 chunk, class_3568 lightProvider, @Nullable BitSet skyBits, @Nullable BitSet blockBits, Operation<class_2672> call,
                                                 @Local(argsOnly = true) class_3244 handler) {
        var storage = new class_2672[1];
        PolymerCommonUtils.executeWithNetworkingLogic(handler, () -> storage[0] = call.call(chunk, lightProvider, skyBits, blockBits));
        return storage[0];
    }

    @WrapWithCondition(method = "unload", at = @At(value = "INVOKE", target = "Lnet/minecraft/server/network/ServerPlayNetworkHandler;sendPacket(Lnet/minecraft/network/packet/Packet;)V"), require = 0)
    private boolean skipChunkClearing(class_3244 instance, class_2596 packet) {
        return PolymerImplUtils.IS_RELOADING_WORLD.get() == null;
    }
}

==> polymer-core-0.14.3+1.21.10-sources.jar: eu/pb4/polymer/core/mixin/block/ChunkDataSenderMixin.java <==
package eu.pb4.polymer.core.mixin.block;

import com.llamalad7.mixinextras.injector.v2.WrapWithCondition;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import eu.pb4.polymer.common.api.PolymerCommonUtils;
import eu.pb4.polymer.core.impl.PolymerImplUtils;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

import java.util.BitSet;
import net.minecraft.class_2596;
import net.minecraft.class_2672;
import net.minecraft.class_2818;
import net.minecraft.class_3244;
import net.minecraft.class_3568;
import net.minecraft.class_8608;

@Mixin(value = class_8608.class, priority = 1001)
public class ChunkDataSenderMixin {
    @WrapOperation(method = "sendChunkData", at = @At(value = "NEW", target = "(Lnet/minecraft/world/chunk/WorldChunk;Lnet/minecraft/world/chunk/light/LightingProvider;Ljava/util/BitSet;Ljava/util/BitSet;)Lnet/minecraft/network/packet/s2c/play/ChunkDataS2CPacket;"), require = 0)
    private static class_2672 addContext(class_2818 chunk, class_3568 lightProvider, @Nullable BitSet skyBits, @Nullable BitSet blockBits, Operation<class_2672> call,
                                                 @Local(argsOnly = true) class_3244 handler) {
        return PolymerCommonUtils.executeWithNetworkingLogic(handler, () -> call.call(chunk, lightProvider, skyBits, blockBits));
    }

    @WrapWithCondition(method = "unload", at = @At(value = "INVOKE", target = "Lnet/minecraft/server/network/ServerPlayNetworkHandler;sendPacket(Lnet/minecraft/network/packet/Packet;)V"), require = 0)
    private boolean skipChunkClearing(class_3244 instance, class_2596 packet) {
        return PolymerImplUtils.IS_RELOADING_WORLD.get() == null;
    }
}
